@@ -16,4 +16,8 @@
 #undef ENABLE_EVOLUTION
 #undef ENABLE_GNOCAM
 #undef GETTEXT_PACKAGE
+#undef GCONFTOOL
+#undef GCONF_CONFIG_SOURCE
+#undef INSTALL_GCONF_CONFIG_SOURCE
+#undef HAVE_EXIF
 
