@@ -44,6 +44,7 @@
 #include <bonobo/bonobo-property-bag.h>
 #include <bonobo/bonobo-zoomable.h>
 #include <bonobo/bonobo-ui-util.h>
+#include <eel/eel-vfs-extensions.h>
 
 #include "eog-wrap-list.h"
 #include "eog-scroll-view.h"
@@ -801,10 +802,7 @@ eog_collection_view_get_prop (BonoboPropertyBag *bag,
 		if (base_uri == NULL)
 			title = g_strdup (_("Collection View"));
 		else {
-			if (g_strncasecmp ("file:", base_uri, 5) == 0)
-				title = g_strdup ((base_uri+5*sizeof(guchar)));
-			else
-				title = g_strdup (base_uri);
+			title = eel_format_uri_for_display (base_uri);
 		}
 
 		BONOBO_ARG_SET_STRING (arg, title);
@@ -1121,13 +1119,20 @@ static GtkWidget*
 create_user_interface (EogCollectionView *list_view)
 {
 	EogCollectionViewPrivate *priv;
+#if HAVE_EXIF
 	GtkWidget *hpaned;
+#endif
 	GtkWidget *vpaned;
 	GtkWidget *sw;
 	GtkWidget *frame;
 	
 	priv = list_view->priv;
 
+	/* the upper part contains the image view, the
+	 * lower part contains the thumbnail list
+	 */
+	vpaned = eog_vertical_splitter_new ();
+
 	/* the image view for the full size image */
  	priv->scroll_view = eog_scroll_view_new ();
 	g_object_set (G_OBJECT (priv->scroll_view), "height_request", 250, NULL);
@@ -1139,23 +1144,34 @@ create_user_interface (EogCollectionView *list_view)
 	gtk_container_add (GTK_CONTAINER (frame), priv->scroll_view);
 
 #if HAVE_EXIF
-	/* info view for additional image information */
+	/* If we have additional information through libexif, we 
+	 * create an info view widget and put it to left of the 
+	 * image view. Using an eog_horizontal_splitter for this. 
+	 */
 	priv->info_view = gtk_widget_new (EOG_TYPE_INFO_VIEW, NULL);
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), 
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 	gtk_container_add (GTK_CONTAINER (sw), priv->info_view);
-#else
-	priv->info_view = NULL;
-	sw = NULL;
-#endif
 
-	hpaned = gtk_hpaned_new (); /* FIXME: use specalised eog splitter */
+	/* left side holds the image view, right side the info view */
+	hpaned = eog_horizontal_splitter_new (); 
 	gtk_paned_pack1 (GTK_PANED (hpaned), frame, TRUE, TRUE);
 	gtk_paned_pack2 (GTK_PANED (hpaned), sw, FALSE, TRUE);
 	gtk_widget_show_all (hpaned);
 
+	gtk_paned_pack1 (GTK_PANED (vpaned), hpaned, TRUE, TRUE);
+
+#else
+	/* If libexif isn't available we put the image view (frame)
+	 * directly into the vpaned created above.
+	 */
+	priv->info_view = NULL;
+	gtk_widget_show_all (frame);
+	gtk_paned_pack1 (GTK_PANED (vpaned), frame, TRUE, TRUE);	
+#endif
+
 	/* the wrap list for all the thumbnails */
 	priv->wraplist = eog_wrap_list_new ();
 	g_object_set (G_OBJECT (priv->wraplist), 
@@ -1174,11 +1190,7 @@ create_user_interface (EogCollectionView *list_view)
 					GTK_POLICY_AUTOMATIC);
 	gtk_container_add (GTK_CONTAINER (sw), priv->wraplist);
 	gtk_widget_show_all (sw);
-
-	/* put it all together */
-	vpaned = eog_vertical_splitter_new ();
 	
-	gtk_paned_pack1 (GTK_PANED (vpaned), hpaned, TRUE, TRUE);
 	gtk_paned_pack2 (GTK_PANED (vpaned), sw, TRUE, TRUE);
 
 	/* by default make the wrap list keyboard active */
